@@ -38,8 +38,8 @@ class TestDataLoader(unittest.TestCase):
         #
         tokenizer = BertTokenizer.from_pretrained('voidful/albert_chinese_tiny')
         feature = tfkit.tag.get_feature_from_data(tokenizer, ["B_Thing", "I_Thing", "O"], "狼 煙 逝 去 ， 幽 夢 醒 來 。",
-                                        target="O O O O O O O O O O", maxlen=5, separator=" ",
-                                        handle_exceed='slide')
+                                                  target="O O O O O O O O O O", maxlen=5, separator=" ",
+                                                  handle_exceed='slide')
         for _ in feature:
             print(_)
 
@@ -56,6 +56,7 @@ class TestDataLoader(unittest.TestCase):
                                                   handle_exceed='end_slice')
         for _ in feature:
             print(_)
+
     def testMask(self):
         for i in tfkit.mask.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'mask.csv')):
             print("get_data_from_file", i)
@@ -94,12 +95,60 @@ class TestDataLoader(unittest.TestCase):
                              get_data_from_file=tfkit.once.get_data_from_file,
                              preprocessing_data=tfkit.once.preprocessing_data,
                              input_arg={'maxlen': maxlen}):
-            # print(tokenizer.convert_tokens_to_string(tokenizer.convert_ids_to_tokens(i['input'])))
-            # print(tokenizer.convert_tokens_to_string(tokenizer.convert_ids_to_tokens(i['target'])))
+            print(tokenizer.convert_tokens_to_string(tokenizer.convert_ids_to_tokens(i['input'])))
+            print(tokenizer.convert_tokens_to_string(tokenizer.convert_ids_to_tokens(i['target'])))
             print(len(i['target']))
             self.assertTrue(len(i['input']) == 512)
             self.assertTrue(len(i['target']) == 512)
 
+    def testOnceCTC(self):
+        tokenizer = BertTokenizer.from_pretrained('voidful/albert_chinese_tiny')
+        for i in tfkit.oncectc.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv')):
+            print(i)
+        maxlen = 10
+        for i in LoadDataset(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv'),
+                             pretrained_config='voidful/albert_chinese_tiny',
+                             get_data_from_file=tfkit.oncectc.get_data_from_file,
+                             preprocessing_data=tfkit.oncectc.preprocessing_data,
+                             input_arg={'maxlen': maxlen}):
+            print(tokenizer.convert_tokens_to_string(tokenizer.convert_ids_to_tokens(i['input'])))
+            print(tokenizer.convert_tokens_to_string(tokenizer.convert_ids_to_tokens(i['target_once'])))
+            print(tokenizer.convert_tokens_to_string(tokenizer.convert_ids_to_tokens(i['target'])))
+            print(i)
+            print(len(i['target']))
+            self.assertTrue(len(i['input']) == maxlen)
+            self.assertTrue(len(i['target']) == maxlen)
+
+    def testCLM(self):
+        tokenizer = BertTokenizer.from_pretrained('voidful/albert_chinese_tiny')
+
+        maxlen = 10
+        feature = tfkit.clm.get_feature_from_data(tokenizer, maxlen, "go go go go go go go", '',
+                                                       target=["hi"],
+                                                       reserved_len=3)[-1]
+        print(feature)
+
+        for i in tfkit.clm.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv')):
+            print(i)
+
+        maxlen = 10
+        for likelihood in ['none', 'neg', 'pos', 'both']:
+            print(likelihood)
+            for i in LoadDataset(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv'),
+                                 pretrained_config='voidful/albert_chinese_tiny',
+                                 get_data_from_file=tfkit.clm.get_data_from_file,
+                                 preprocessing_data=tfkit.clm.preprocessing_data,
+                                 input_arg={'maxlen': maxlen, 'likelihood': likelihood}):
+                start_pos = i['start']
+                print(likelihood, i)
+                # self.assertTrue(tokenizer.mask_token_id == i['input'][start_pos])
+                if 'neg' in likelihood and i['target'][start_pos] == -1:
+                    self.assertTrue(i['ntarget'][start_pos] != -1)
+                else:
+                    self.assertTrue(i['target'][start_pos] != -1)
+                self.assertTrue(len(i['input']) == maxlen)
+                self.assertTrue(len(i['target']) == maxlen)
+
     def testOnebyone(self):
         tokenizer = BertTokenizer.from_pretrained('voidful/albert_chinese_tiny')
 
@@ -122,7 +171,7 @@ class TestDataLoader(unittest.TestCase):
                                  preprocessing_data=tfkit.onebyone.preprocessing_data,
                                  input_arg={'maxlen': maxlen, 'likelihood': likelihood}):
                 start_pos = i['start']
-                print(i)
+                print(likelihood, i)
                 self.assertTrue(tokenizer.mask_token_id == i['input'][start_pos])
                 if 'neg' in likelihood and i['target'][start_pos] == -1:
                     self.assertTrue(i['ntarget'][start_pos] != -1)
@@ -142,7 +191,7 @@ class TestDataLoader(unittest.TestCase):
                                  preprocessing_data=tfkit.onebyone.preprocessing_data,
                                  input_arg={'maxlen': maxlen, 'likelihood': likelihood}):
                 start_pos = i['start']
-                output.append(tokenizer.convert_ids_to_tokens(i['target'])[start_pos])
+                output.extend(tokenizer.convert_ids_to_tokens([i['target'][start_pos]]))
                 print(output)
             print(tokenizer.convert_tokens_to_string(output) + "\n")
 
@@ -204,3 +253,27 @@ class TestDataLoader(unittest.TestCase):
         ds.increase_with_sampling(50)
         print("after increase_with_sampling", ds.__len__())
         self.assertTrue(ds.__len__() == 50)
+
+    def testSeq2seq(self):
+        tokenizer = BertTokenizer.from_pretrained('voidful/albert_chinese_tiny')
+
+        maxlen = 10
+        feature = tfkit.seq2seq.get_feature_from_data(tokenizer, maxlen, "go go go go go go go", '',
+                                                      target=["hi"],
+                                                      reserved_len=3)[-1]
+        print("feature", feature)
+
+        for i in tfkit.seq2seq.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv')):
+            print("data", i)
+
+        maxlen = 10
+        for likelihood in ['none', 'neg', 'pos', 'both']:
+            print(likelihood)
+            for i in LoadDataset(os.path.join(TestDataLoader.DATASET_DIR, 'gen_eng.csv'),
+                                 pretrained_config='prajjwal1/bert-small',
+                                 get_data_from_file=tfkit.seq2seq.get_data_from_file,
+                                 preprocessing_data=tfkit.seq2seq.preprocessing_data,
+                                 input_arg={'maxlen': maxlen, 'likelihood': likelihood}):
+                print(likelihood, i)
+                self.assertTrue(len(i['input']) == maxlen)
+                self.assertTrue(len(i['target']) == maxlen)
